@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//--------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 2001-2005 Simon Howard
 //
@@ -10,19 +6,11 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//--------------------------------------------------------------------------
 //
 // SDL Video Code
 //
-// By Simon Howard
-//
-//-----------------------------------------------------------------------
 
 #include <string.h>
 #include <time.h>
@@ -51,7 +39,7 @@ static SDL_Color cga_pal[] = {
 #endif
 };
 
-BOOL vid_fullscreen = FALSE;
+bool vid_fullscreen = false;
 
 extern unsigned char *vid_vram;
 extern unsigned int vid_pitch;
@@ -72,8 +60,8 @@ int keybindings[NUM_KEYS] = {
 };
 
 static int ctrlbreak = 0;
-static BOOL initted = 0;
-static SDL_Window *window;
+static bool initted = 0;
+static SDL_Window *window = NULL;
 static uint32_t pixel_format;
 static SDL_Renderer *renderer;
 
@@ -94,7 +82,7 @@ static SDL_Texture *texture_upscaled = NULL;
 
 // convert a sopsym_t into a surface
 #define ICON_SCALE 4
-SDL_Surface *surface_from_sopsym(sopsym_t *sym)
+static SDL_Surface *surface_from_sopsym(sopsym_t *sym)
 {
 	SDL_Surface *surface = SDL_CreateRGBSurface(
 		0, sym->w * ICON_SCALE, sym->h * ICON_SCALE, 32,
@@ -172,7 +160,7 @@ void Vid_Update(void)
 	SDL_LockSurface(screenbuf);
 }
 
-static BOOL is_special_day(void)
+static bool is_special_day(void)
 {
 	time_t now = time(NULL);
 	struct tm *t = localtime(&now);
@@ -222,9 +210,8 @@ static void LimitTextureSize(int *w_upscale, int *h_upscale)
 
 	// Query renderer and limit to maximum texture dimensions of hardware:
 	if (SDL_GetRendererInfo(renderer, &rinfo) != 0) {
-		fprintf(stderr, "CreateUpscaledTexture: SDL_GetRendererInfo() "
-		                "call failed: %s\n", SDL_GetError());
-		exit(1);
+		error_exit("CreateUpscaledTexture: SDL_GetRendererInfo() "
+		           "call failed: %s", SDL_GetError());
 	}
 
 	while (*w_upscale * SCR_WDTH > rinfo.max_texture_width) {
@@ -236,11 +223,10 @@ static void LimitTextureSize(int *w_upscale, int *h_upscale)
 
 	if ((*w_upscale < 1 && rinfo.max_texture_width > 0)
 	 || (*h_upscale < 1 && rinfo.max_texture_height > 0)) {
-		fprintf(stderr, "CreateUpscaledTexture: Can't create a "
-		                "texture big enough for the whole screen! "
-		                "Maximum texture size %dx%d\n",
-		        rinfo.max_texture_width, rinfo.max_texture_height);
-		exit(1);
+		error_exit("CreateUpscaledTexture: Can't create a "
+		           "texture big enough for the whole screen! "
+		           "Maximum texture size %dx%d",
+		           rinfo.max_texture_width, rinfo.max_texture_height);
 	}
 
 	// We limit the amount of texture memory used for the intermediate buffer,
@@ -249,11 +235,10 @@ static void LimitTextureSize(int *w_upscale, int *h_upscale)
 	// huge textures, so the user can use this to reduce the maximum texture
 	// size if desired.
 	if (max_scaling_buffer_pixels < SCR_WDTH * SCR_HGHT) {
-		fprintf(stderr, "CreateUpscaledTexture: max_scaling_buffer_"
-		                "pixels too small to create a texture buffer:"
-		                " %d < %d\n", max_scaling_buffer_pixels,
-		                SCR_WDTH * SCR_HGHT);
-		exit(1);
+		error_exit("CreateUpscaledTexture: max_scaling_buffer_"
+		           "pixels too small to create a texture buffer:"
+		           " %d < %d", max_scaling_buffer_pixels,
+		           SCR_WDTH * SCR_HGHT);
 	}
 
 	while (*w_upscale * *h_upscale * SCR_WDTH * SCR_HGHT
@@ -267,7 +252,7 @@ static void LimitTextureSize(int *w_upscale, int *h_upscale)
 
 	if (*w_upscale != orig_w || *h_upscale != orig_h) {
 		printf("CreateUpscaledTexture: Limited texture size to %dx%d "
-		       "(max %d pixels, max texture size %dx%d)\n",
+		       "(max %d pixels, max texture size %dx%d)",
 		       *w_upscale * SCR_WDTH, *h_upscale * SCR_HGHT,
 		       max_scaling_buffer_pixels, rinfo.max_texture_width,
 		       rinfo.max_texture_height);
@@ -285,9 +270,7 @@ static void CreateUpscaledTexture(int force)
 	// real world pixels, which are not necessarily equivalent to the
 	// screen's window size (because of highdpi).
 	if (SDL_GetRendererOutputSize(renderer, &w, &h) != 0) {
-		fprintf(stderr, "failed to get renderer size: %s\n",
-		        SDL_GetError());
-		exit(1);
+		error_exit("failed to get renderer size: %s", SDL_GetError());
 	}
 
 	// When the screen or window dimensions do not match the aspect ratio
@@ -377,9 +360,8 @@ static void Vid_SetMode(void)
 	int bpp;
 
 	if (SDL_Init(SDL_INIT_VIDEO) < 0) {
-		fprintf(stderr, "Unable to initialize video subsystem: %s\n",
-		                SDL_GetError());
-		exit(-1);
+		error_exit("Unable to initialize video subsystem: %s",
+		           SDL_GetError());
 	}
 	srand(time(NULL));
 
@@ -391,13 +373,11 @@ static void Vid_SetMode(void)
 		flags |= SDL_WINDOW_FULLSCREEN_DESKTOP;
 	}
 
-	window = SDL_CreateWindow(PACKAGE_STRING, SDL_WINDOWPOS_UNDEFINED,
-	                          SDL_WINDOWPOS_UNDEFINED, w, h, flags);
+	window = SDL_CreateWindow(PACKAGE_STRING, SDL_WINDOWPOS_CENTERED,
+	                          SDL_WINDOWPOS_CENTERED, w, h, flags);
 
 	if (window == NULL) {
-		fprintf(stderr, "Failed to open SDL window: %s\n",
-		        SDL_GetError());
-		exit(-1);
+		error_exit("Failed to open SDL window: %s", SDL_GetError());
 	}
 
         pixel_format = SDL_GetWindowPixelFormat(window);
@@ -555,21 +535,21 @@ static sopkey_t translate_scancode(int sdl_scancode)
 
 // Special keys get passed through as input events even when text input mode
 // is activated.
-static BOOL IsSpecialKey(SDL_Keysym *k) {
+static bool IsSpecialKey(SDL_Keysym *k) {
 	switch (k->sym) {
 		case SDLK_ESCAPE:
 		case SDLK_RETURN:
 		case SDLK_BACKSPACE:
-			return TRUE;
+			return true;
 		default:
-			return FALSE;
+			return false;
 	}
 }
 
 static void getevents(void)
 {
 	SDL_Event event;
-	static BOOL ctrldown = 0, altdown = 0;
+	static bool ctrldown = 0, altdown = 0;
 	int need_redraw = 0;
 	int i;
 	sopkey_t translated;
@@ -638,11 +618,18 @@ static void getevents(void)
 			break;
 
 		case SDL_WINDOWEVENT:
-			// When we get one of these events, we redraw
-			// the screen immediately, as we may be in a
-			// menu waiting for a keypress.
-			need_redraw = 1;
-			break;
+			switch (event.window.event) {
+			case SDL_WINDOWEVENT_CLOSE:
+				exit(0);
+				break;
+
+			default:
+				// When we get one of these events, we redraw
+				// the screen immediately, as we may be in a
+				// menu waiting for a keypress.
+				need_redraw = 1;
+				break;
+			}
 		}
 	}
 
@@ -680,7 +667,7 @@ int Vid_GetChar(void)
 	return result;
 }
 
-BOOL Vid_GetCtrlBreak(void)
+bool Vid_GetCtrlBreak(void)
 {
 	getevents();
 	return ctrlbreak;
@@ -706,47 +693,31 @@ char *Vid_GetPrefPath(void)
 	return result;
 }
 
-//-----------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.8  2005/06/01 10:17:26  fraggle
-// Don't #include files with drawing functions.
-// Include README files for psion and gtk ports.
-// Remove unnecessary include parameter.
-//
-// Revision 1.7  2005/04/29 19:25:29  fraggle
-// Update copyright to 2005
-//
-// Revision 1.6  2005/04/28 14:52:55  fraggle
-// Fix compilation under gcc 4.0
-//
-// Revision 1.5  2004/10/15 17:30:58  fraggle
-// Always hide the cursor.
-//
-// Revision 1.4  2004/10/14 08:48:46  fraggle
-// Wrap the main function in system-specific code.  Remove g_argc/g_argv.
-// Fix crash when unable to initialise video subsystem.
-//
-// Revision 1.3  2003/03/26 13:53:29  fraggle
-// Allow control via arrow keys
-// Some code restructuring, system-independent video.c added
-//
-// Revision 1.2  2003/03/26 12:02:38  fraggle
-// Apply patch from David B. Harris (ElectricElf) for right ctrl key and
-// documentation
-//
-// Revision 1.1.1.1  2003/02/14 19:03:37  fraggle
-// Initial Sourceforge CVS import
-//
-//
-// sdh 14/2/2003: change license header to GPL
-// sdh 25/04/2002: rename vga_{pitch,vram} to vid_{pitch,vram}
-// sdh 26/03/2002: now using platform specific vga code for drawing stuff
-//                 (#include "vid_vga.c")
-//                 rename CGA_ to Vid_
-// sdh 17/11/2001: buffered input for keypresses,
-//                 CGA_GetLastKey->CGA_GetKey
-// sdh 07/11/2001: add CGA_Reset
-// sdh 21/10/2001: added cvs tags
-//
-//-----------------------------------------------------------------------
+#ifdef HAVE_ISATTY
+#include <unistd.h>
+#else
+int isatty(int fd)
+{
+	return 0;
+}
+#endif
+
+void error_exit(char *s, ...)
+{
+	static char buf[128];
+	va_list args;
+
+	va_start(args, s);
+	vsnprintf(buf, sizeof(buf), s, args);
+	va_end(args);
+
+	if (!isatty(1)) {
+		if (SDL_ShowSimpleMessageBox(
+			SDL_MESSAGEBOX_ERROR, "Error", buf, window) == 0) {
+			exit(1);
+		}
+	}
+
+	fprintf(stderr, "%s\n", buf);
+	exit(1);
+}
