@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//---------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 1984-2000 David L. Clark
 // Copyright(C) 2001-2005 Simon Howard
@@ -11,17 +7,11 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//---------------------------------------------------------------------------
 //
 //        sw.h     -      SW  Manifest Definitions
 //
-//---------------------------------------------------------------------------
 
 #ifndef __SW_H__
 #define __SW_H__
@@ -31,6 +21,10 @@
 #include "swsymbol.h"
 #include "config.h"
 
+#if defined(HAVE_NETINET_IN_H) || defined(HAVE_WINSOCK_H)
+#define TCPIP
+#endif
+
 #ifdef _MSC_VER
 #define inline __inline
 #define strcasecmp stricmp
@@ -39,7 +33,8 @@
 
 /*  Constants  */
 
-#define MAX_X           3000            /*  Maximum X coordinate            */
+#define FPS             10              /* How fast the game runs */
+
 #define MAX_Y           200             /*  Maximum Y coordinate            */
 #define MIN_SPEED       4               /*  Minimum plane speed             */
 #define MAX_SPEED       8               /*  Maximum plane speed             */
@@ -54,16 +49,12 @@
 #define SCR_HGHT        200             /*  Screen Height                   */
 
 #define SCR_CENTR       ((SCR_WDTH / 2) - 8) /*  Centre column of screen */
-#define SCR_SEGM        0xB800          /*  Screen Video segment            */
-#define SCR_ROFF        0x2000          /*  Screen odd rastor line offset   */
-#define SCR_LINW        80              /*  Screen line width in bytes      */
 #define SCR_MNSH        16              /*  Minumum line number to shift    */
 #define SCR_MXSH        75              /*  Maximum line number to shift    */
-#define SCR_LIMIT       180             /*  Screen shift limits             */
 
 // sdh 27/7/2002: make these independent of the screen width
 
-#define WRLD_RSX        (MAX_X / 320 * 2 + 1) /*  World display X and  */
+#define WRLD_RSX        (currgame->gm_max_x / 320 * 2 + 1) /*  World display X and  */
 #define WRLD_RSY        (MAX_Y / SCR_MNSH + 1)     /*  Y divisors           */
 
 #define GAUGEX          (SCR_CENTR - 25)  /* X co-ordinate of first gauge */
@@ -80,15 +71,13 @@ typedef enum {
 #define MAXBOMBS        5               /* Maximum number of bombs available*/
 #define MAXMISSILES     5               /* Maximum number of missiles       */
 #define MAXBURSTS       5               /* Maximum nuber of starbursts      */
-#define MAXFUEL         ( 3 * MAX_X )   /* Maximum Number of turns between  */
+#define MAXFUEL         9000            /* Maximum number of turns between  */
                                         /*  refuellings                     */
 #define MAXCRASH        5               /* Mximum number of crashes allowed */
 
 #define MAX_PLYR        4               /* Maximum number of players        */
-#define MAX_TARG        128             /* Maximum number of targets        */
 #define MAX_OBJS        100             /* Maximum number of objects        */
 #define NUM_STRAY_BIRDS 1               /* Number of stray birds per flock  */
-#define MAX_GAME        7               /* Maximum number of games          */
 
 #define ANGLES          16              /*  Number of angle increments      */
 #define ORIENTS         2               /*  Number of plane orientations    */
@@ -143,9 +132,7 @@ typedef enum {
 } obtype_t;
 
 #define NEAR            ( 150 * 150 )   /* Computer control distances        */
-#define NEARAPPROACH    200
 #define CLOSE           32
-#define DEADON          ( 4 * 4 )
 #define HOME            16
 #define SAFERESET       32
 
@@ -198,6 +185,7 @@ typedef struct {
 	int		ribbons_nr;	/* Awarded # of ribbons */
 	int		ribbons[6];	/* Ribbon display order */
 	unsigned int	medals;		/* See below */
+	bool            combatwound;    /* If true, wounding came from a bullet */
 } score_t;
 
 #define MEDAL_PURPLEHEART	(1<<0)	/* Returned when damaged */
@@ -245,10 +233,10 @@ typedef struct obj {                            /*  Object list             */
 	struct obj    *ob_next;
 	struct obj    *ob_prev;
 	int            ob_index;
-	BOOL           ob_drwflg;
-	BOOL           ob_onmap;
+	bool           ob_drwflg;
+	bool           ob_onmap;
 	void        ( *ob_drawf ) (struct obj *);
-	BOOL        ( *ob_movef ) (struct obj *);
+	bool        ( *ob_movef ) (struct obj *);
 	struct obj    *ob_xnext;
 	struct obj    *ob_xprev;
 	int            ob_crashcnt;
@@ -256,7 +244,6 @@ typedef struct obj {                            /*  Object list             */
 	int            ob_bdelay;
 	int            ob_home;
 	obtype_t       ob_type;
-	struct obj    *ob_dnext;
 	int            ob_athome;
 	struct tt     *ob_sound;
 	int            ob_missiles;
@@ -268,7 +255,7 @@ typedef struct obj {                            /*  Object list             */
 	int            ob_bsdelay;
 	int            ob_plrnum;
 	obendstatus_t  ob_endsts;
-	BOOL           ob_goingsun;
+	bool           ob_goingsun;
 	score_t	       ob_score;
 	score_t	       ob_lastscore;
 	original_ob_t *ob_original_ob;
@@ -276,8 +263,11 @@ typedef struct obj {                            /*  Object list             */
 
 typedef struct {                                /*  Game structure          */
 	original_ob_t gm_planes[MAX_PLYR*2];
-	unsigned gm_rseed;
-	original_ob_t gm_targets[MAX_TARG];
+	unsigned int gm_rseed;
+	original_ob_t *gm_targets;
+	unsigned int gm_num_targets;
+	GRNDTYPE *gm_ground;
+	unsigned int gm_max_x;  // Defines length of gm_ground[] array.
 }       GAMES;
 
 extern int sintab[ANGLES];
@@ -290,57 +280,14 @@ static inline int SIN(int x) {
 	return sintab[x % ANGLES];
 }
 
+// Evalutes to length of static arrays.
+#define arrlen(x) (sizeof(x) / sizeof(*x))
+
 #endif
 
-//---------------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.15  2005/04/29 19:25:28  fraggle
-// Update copyright to 2005
-//
-// Revision 1.14  2005/04/29 17:20:05  fraggle
-// Fix spelling error: guage -> gauge
-//
-// Revision 1.13  2005/04/29 11:20:26  fraggle
-// Remove ghost planes.  Split off status bar code into a separate file.
-//
-// Revision 1.12  2005/04/29 10:10:12  fraggle
-// "Medals" feature
-// By Christoph Reichenbach <creichen@gmail.com>
-//
-// Revision 1.11  2004/10/25 20:02:11  fraggle
-// Fix spelling error: guage -> gauge
-//
-// Revision 1.10  2004/10/25 19:58:06  fraggle
-// Remove 'goingsun' global variable
-//
-// Revision 1.9  2004/10/20 19:00:01  fraggle
-// Remove currobx, endsts variables
-//
-// Revision 1.8  2004/10/15 21:30:57  fraggle
-// Improve multiplayer
-//
-// Revision 1.7  2004/10/15 18:51:24  fraggle
-// Fix the map. Rename dispworld to dispmap as this is what it really does.
-//
-// Revision 1.6  2003/06/16 02:03:50  fraggle
-// Pseudo-MSVC support..
-//
-// Revision 1.5  2003/06/08 02:39:25  fraggle
-// Initial code to remove XOR based drawing
-//
-// Revision 1.4  2003/06/04 15:49:05  fraggle
-// Removed and unused #define
-//
-// Revision 1.3  2003/04/05 22:48:34  fraggle
-// Remove archaic swmach.h and all IBMPC/ATARI #defines
-//
-// Revision 1.2  2003/04/05 22:31:29  fraggle
-// Remove PLAYMODE_MULTIPLE and swnetio.c
-//
-// Revision 1.1.1.1  2003/02/14 19:03:29  fraggle
-// Initial Sourceforge CVS import
 //
+// 2003-02-14: Code was checked into version control; no further entries
+// will be added to this log.
 //
 // sdh 14/2/2003: change license header to GPL
 // sdh 27/07/2002: made some constants independent of screen width
@@ -367,5 +314,3 @@ static inline int SIN(int x) {
 // 84-06-12        PCjr Speed-up
 // 84-02-02        Development
 //
-//---------------------------------------------------------------------------
-
