@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//---------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 1984-2000 David L. Clark
 // Copyright(C) 2001-2005 Simon Howard
@@ -11,28 +7,24 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//---------------------------------------------------------------------------
 //
 //        swcollsn -      SW collision resolution
 //
-//---------------------------------------------------------------------------
 
 #include "sw.h"
 #include "swcollsn.h"
 #include "swend.h"
-#include "swground.h"
 #include "swinit.h"
 #include "swmain.h"
 #include "swmove.h"
 #include "swsound.h"
 #include "swsplat.h"
 
+static void tstcrash(OBJECTS *obp);
+static void blast_target(OBJECTS *ob, obtype_t type);
+
 static OBJECTS *killed[MAX_OBJS*2], *killer[MAX_OBJS*2];
 static int killptr;
 
@@ -185,7 +177,7 @@ static void scoretarg(OBJECTS *obp, int score)
 }
 
 
-static BOOL scorepenalty(obtype_t ttype, OBJECTS * ob, int score)
+static bool scorepenalty(obtype_t ttype, OBJECTS * ob, int score)
 {
 	OBJECTS *obt;
 
@@ -198,9 +190,9 @@ static BOOL scorepenalty(obtype_t ttype, OBJECTS * ob, int score)
 			&& obt->ob_hitcount == FALLCOUNT))
 		&& !obt->ob_athome)) {
 		scoretarg(obt, score);
-		return TRUE;
+		return true;
 	}
-	return FALSE;
+	return false;
 }
 
 
@@ -219,7 +211,7 @@ static void crater(OBJECTS * ob)
 	for (x = xmin, i = 0; x <= xmax; ++x, ++i) {
 		ymax = ground[x];
 		ymin = ymax - crtdepth[i] +1;
-		y = orground[x] - 20;
+		y = currgame->gm_ground[x] - 20;
 		if (y < 20) {
 			y = 20;
 		}
@@ -228,7 +220,6 @@ static void crater(OBJECTS * ob)
 		}
 		ground[x] = ymin - 1;
 	}
-	forcdisp = TRUE;
 }
 
 /* Determine whether the parameter is a shot and hasn't moved very much yet;
@@ -240,9 +231,6 @@ is_young_shot(OBJECTS *ob)
 	return (ob && ob->ob_type == SHOT && ob->ob_life >= BULLIFE - 1);
 }
 
-
-void blast_target(OBJECTS *ob, obtype_t type);
-
 static void swkill(OBJECTS * ob1, OBJECTS * ob2)
 {
 	OBJECTS *ob, *obt;
@@ -307,7 +295,7 @@ static void swkill(OBJECTS * ob1, OBJECTS * ob2)
 		}
 
 		ob->ob_state = FINISHED;
-		ob->ob_onmap = FALSE;
+		ob->ob_onmap = false;
 		initexpl(ob, 0);
 
 		blast_target(ob, ttype);
@@ -387,7 +375,15 @@ static void swkill(OBJECTS * ob1, OBJECTS * ob2)
 				}
 			}
 
-			if (conf_wounded) {
+			// Wounding is only allowed if the player is actually
+			// in the air. If an enemy plane scores a hit on a
+			// player sitting on the runway, that is a successful
+			// raid; otherwise, the damage would be repaired
+			// immediately.
+			if (conf_wounded && !ob->ob_athome) {
+				if (ttype == SHOT) {
+					ob->ob_score.combatwound = true;
+				}
 				if (state == FLYING) {
 					ob->ob_state = WOUNDED;
 					return;
@@ -500,7 +496,7 @@ void swcollsn(void)
 	}
 }
 
-void tstcrash(OBJECTS * obp)
+static void tstcrash(OBJECTS *obp)
 {
 	sopsym_t *sym = obp->ob_newsym;
 	int x, y;
@@ -534,7 +530,7 @@ void tstcrash(OBJECTS * obp)
 
 /* Determine valour factor */
 
-int compute_valour(OBJECTS *ob)
+static int compute_valour(OBJECTS *ob)
 {
 	int reverse;
 	OBJECTS *so = get_score_obj(ob, &reverse);
@@ -577,7 +573,7 @@ int compute_valour(OBJECTS *ob)
 	return valour;
 }
 
-void blast_target(OBJECTS *ob, obtype_t type)
+static void blast_target(OBJECTS *ob, obtype_t type)
 {
 	int reverse;
 	OBJECTS *so = get_score_obj(ob, &reverse);
@@ -614,71 +610,9 @@ void scorepln(OBJECTS * ob, obtype_t type)
 	}
 }
 
-
-//---------------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.18  2005/04/29 19:25:28  fraggle
-// Update copyright to 2005
-//
-// Revision 1.17  2005/04/29 18:57:12  fraggle
-// Move dispscore and medal drawing code into swstbar.c
-//
-// Revision 1.16  2005/04/29 11:20:27  fraggle
-// Remove ghost planes.  Split off status bar code into a separate file.
-//
-// Revision 1.15  2005/04/29 10:31:10  fraggle
-// Remove destroyed objects from the map
-//
-// Revision 1.14  2005/04/29 10:10:12  fraggle
-// "Medals" feature
-// By Christoph Reichenbach <creichen@gmail.com>
-//
-// Revision 1.13  2005/04/29 09:13:25  fraggle
-// Fix planes running into their own bullets
-// (From Christoph Reichenbach <creichen@gmail.com>)
-//
-// Revision 1.12  2004/10/20 19:00:01  fraggle
-// Remove currobx, endsts variables
-//
-// Revision 1.11  2004/10/20 18:12:57  fraggle
-// Fix incorrect endgames when numtargs < 0
-//
-// Revision 1.10  2004/10/15 21:30:58  fraggle
-// Improve multiplayer
-//
-// Revision 1.9  2004/10/15 18:51:24  fraggle
-// Fix the map. Rename dispworld to dispmap as this is what it really does.
-//
-// Revision 1.8  2004/10/15 17:52:31  fraggle
-// Clean up compiler warnings. Rename swmisc.c -> swtext.c as this more
-// accurately describes what the file does.
-//
-// Revision 1.7  2004/10/15 17:23:32  fraggle
-// Restore HUD splats
-//
-// Revision 1.6  2004/10/15 16:39:32  fraggle
-// Unobfuscate some parts
-//
-// Revision 1.5  2003/06/08 18:41:01  fraggle
-// Merge changes from 1.7.0 -> 1.7.1 into HEAD
-//
-// Revision 1.4  2003/06/08 03:41:41  fraggle
-// Remove auxdisp buffer totally, and all associated functions
-//
-// Revision 1.3.2.1  2003/06/08 18:16:38  fraggle
-// Fix networking and some compile bugs
-//
-// Revision 1.3  2003/04/05 22:44:04  fraggle
-// Remove some useless functions from headers, make them static if they
-// are not used by other files
-//
-// Revision 1.2  2003/04/05 22:31:29  fraggle
-// Remove PLAYMODE_MULTIPLE and swnetio.c
-//
-// Revision 1.1.1.1  2003/02/14 19:03:09  fraggle
-// Initial Sourceforge CVS import
 //
+// 2003-02-14: Code was checked into version control; no further entries
+// will be added to this log.
 //
 // sdh 14/2/2003: change license header to GPL
 // sdh 28/07/2002: removed old collision detection code
@@ -706,4 +640,3 @@ void scorepln(OBJECTS * ob, obtype_t type)
 // 84-06-12        PCjr Speed-up
 // 84-02-02        Development
 //
-//---------------------------------------------------------------------------
