@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//---------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 1984-2000 David L. Clark
 // Copyright(C) 2001-2005 Simon Howard
@@ -11,17 +7,11 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//---------------------------------------------------------------------------
 //
 //        swinit   -      SW initialization
 //
-//---------------------------------------------------------------------------
 
 #include <stdio.h>
 #include <string.h>
@@ -37,7 +27,6 @@
 #include "swdisp.h"
 #include "swinit.h"
 #include "swgames.h"
-#include "swground.h"
 #include "swmain.h"
 #include "swmove.h"
 #include "swobject.h"
@@ -45,7 +34,8 @@
 #include "swsplat.h"
 #include "swsymbol.h"
 #include "swtitle.h"
-#include "swutil.h"
+
+GRNDTYPE *ground;
 
 static int have_savescore = 0;
 static score_t savescore;		/* save players score on restart  */
@@ -101,9 +91,12 @@ static void initobjs(void)
 }
 
 
-static void initgrnd(void)
+void initgrnd(void)
 {
-	memcpy(ground, orground, sizeof(GRNDTYPE) * MAX_X);
+	free(ground);
+	ground = calloc(currgame->gm_max_x, sizeof(GRNDTYPE));
+	memcpy(ground, currgame->gm_ground,
+	       sizeof(GRNDTYPE) * currgame->gm_max_x);
 }
 
 static void initseed(void)
@@ -112,7 +105,7 @@ static void initseed(void)
 	explseed = rand() % 65536;
 }
 
-void initdisp(BOOL reset)
+void initdisp(bool reset)
 {
 	swclearsplats();
 	if (!reset) {
@@ -126,8 +119,7 @@ void initdisp(BOOL reset)
 //
 
 
-void
-initplanescore (score_t *score)
+static void initplanescore (score_t *score)
 {
 	score->planekills = 0;
 	score->medals = 0x0000;
@@ -143,27 +135,25 @@ initplanescore (score_t *score)
 #define VALOUR_PRELIMIT 175
 #define VALOUR_LIMIT 250
 
-void
-give_medal (OBJECTS *ob, int medal_id)
+static void give_medal(OBJECTS *ob, int medal_id)
 {
 	ob->ob_score.medalslist[ob->ob_score.medals_nr++] = medal_id;
 }
 
-void
-give_ribbon (OBJECTS *ob, int ribbon_id)
+static void give_ribbon(OBJECTS *ob, int ribbon_id)
 {
 	ob->ob_score.ribbons[ob->ob_score.ribbons_nr++] = ribbon_id;
 }
 
-void
-get_awards (OBJECTS *ob)
+static void get_awards(OBJECTS *ob)
 {
 	score_t *lsc = &ob->ob_lastscore;
 	score_t *sc = &ob->ob_score;
 
 	if (!(lsc->medals & MEDAL_PURPLEHEART)) {
-		if (ob->ob_state == WOUNDED
-		    || ob->ob_state == WOUNDSTALL) {
+		// We only award purple heart if wounded in combat (=hit by
+		// bullet), not from a bird strike or flying into an ox
+		if (ob->ob_score.combatwound) {
 			sc->medals |= MEDAL_PURPLEHEART;
 			give_medal(ob, MEDAL_ID_PURPLEHEART);
 		}
@@ -222,8 +212,7 @@ get_awards (OBJECTS *ob)
 	ob->ob_lastscore = ob->ob_score;
 }
 
-void
-get_endlevel (OBJECTS *ob)
+static void get_endlevel(OBJECTS *ob)
 {
 	score_t *sc = &ob->ob_score;
 	score_t *lsc = &ob->ob_lastscore;
@@ -279,10 +268,11 @@ OBJECTS *initpln(OBJECTS * obp)
 	ob->ob_angle = (ob->ob_orient) ? (ANGLES / 2) : 0;
 	ob->ob_target = ob->ob_missiletarget = NULL;
 	ob->ob_firing = ob->ob_mfiring = NULL;
-	ob->ob_bombing = ob->ob_bfiring = ob->ob_home = FALSE;
+	ob->ob_bombing = ob->ob_bfiring = ob->ob_home = false;
 	ob->ob_newsym = symbol_plane[ob->ob_orient][0];
-	ob->ob_athome = TRUE;
-	ob->ob_onmap = TRUE;
+	ob->ob_athome = true;
+	ob->ob_onmap = true;
+	ob->ob_score.combatwound = false;
 
 	if (!obp || ob->ob_state == CRASHED) {
 		/* New plane */
@@ -291,10 +281,10 @@ OBJECTS *initpln(OBJECTS * obp)
 		ob->ob_missiles = MAXMISSILES;
 		ob->ob_bursts = MAXBURSTS;
 		ob->ob_life = MAXFUEL;
-		initplanescore(&ob->ob_score);
 		initplanescore(&ob->ob_lastscore);
 	}
 	if (!obp) {
+		initplanescore(&ob->ob_score);
 		ob->ob_score.score = ob->ob_crashcnt = 0;
 		ob->ob_endsts = PLAYING;
 		ob->ob_target = NULL;
@@ -305,7 +295,7 @@ OBJECTS *initpln(OBJECTS * obp)
 	}
 
 	ob->ob_state = FLYING;
-	ob->ob_goingsun = FALSE;
+	ob->ob_goingsun = false;
 
 	return ob;
 }
@@ -361,7 +351,7 @@ void initcomp(OBJECTS * obp)
 	}
 	if (playmode == PLAYMODE_SINGLE || playmode == PLAYMODE_NOVICE) {
 		ob->ob_state = FINISHED;
-		ob->ob_onmap = FALSE;
+		ob->ob_onmap = false;
 		deletex(ob);
 	}
 }
@@ -475,7 +465,7 @@ void initbomb(OBJECTS *obo)
 	ob->ob_state = FALLING;
 	ob->ob_dx = obo->ob_dx;
 	ob->ob_dy = obo->ob_dy;
-	ob->ob_onmap = TRUE;
+	ob->ob_onmap = true;
 
 	if (obo->ob_orient) {
 		angle = (obo->ob_angle + (ANGLES / 4)) % ANGLES;
@@ -534,11 +524,11 @@ void initmiss(OBJECTS *obo)
 	ob->ob_owner = obo;
 	ob->ob_clr = obo->ob_clr;
 	ob->ob_newsym = symbol_missile[0];
-	ob->ob_drawf = dispmiss;
+	ob->ob_drawf = NULL;
 	ob->ob_movef = movemiss;
 	ob->ob_missiletarget = obo->ob_mfiring;
 	ob->ob_orient = ob->ob_accel = ob->ob_flaps = 0;
-	ob->ob_onmap = TRUE;
+	ob->ob_onmap = true;
 
 	insertx(ob, obo);
 
@@ -588,7 +578,7 @@ void initburst(OBJECTS *obo)
 	ob->ob_owner = obo;
 	ob->ob_clr = obo->ob_clr;
 	ob->ob_newsym = symbol_burst[0];
-	ob->ob_drawf = dispburst;
+	ob->ob_drawf = NULL;
 	ob->ob_movef = moveburst;
 
 	insertx(ob, obo);
@@ -655,7 +645,7 @@ static OBJECTS *inittarget(original_ob_t *orig_ob)
 	ob->ob_newsym = symbol_targets[0];
 	ob->ob_drawf = disptarg;
 	ob->ob_movef = movetarg;
-	ob->ob_onmap = TRUE;
+	ob->ob_onmap = true;
 
 	return ob;
 }
@@ -669,7 +659,7 @@ void initexpl(OBJECTS *obo, int small)
 	// int life;
 	int obox, oboy, obodx, obody, oboclr;
 	obtype_t obotype;
-	BOOL mansym;
+	bool mansym;
 	int orient;
 
 	obox = obo->ob_x + (obo->ob_newsym->w / 2);
@@ -786,16 +776,16 @@ static OBJECTS *initflock(original_ob_t *orig_ob)
 	ob->ob_state = FLYING;
 	ob->ob_x = orig_ob->x;
 	ob->ob_y = MAX_Y - 1;
-	ob->ob_dx = ob->ob_x < (MAX_X / 2) ? 2 : -2;
+	ob->ob_dx = ob->ob_x < (currgame->gm_max_x / 2) ? 2 : -2;
 	ob->ob_dy = ob->ob_lx = ob->ob_ly = ob->ob_ldx = ob->ob_ldy = 0;
 	ob->ob_orient = 0;
 	ob->ob_life = FLOCKLIFE;
 	ob->ob_owner = ob;
 	ob->ob_newsym = symbol_flock[0];
-	ob->ob_drawf = dispflck;
+	ob->ob_drawf = NULL;
 	ob->ob_movef = moveflck;
 	ob->ob_clr = 9;
-	ob->ob_onmap = TRUE;
+	ob->ob_onmap = true;
 
 	for (j = 0; j < NUM_STRAY_BIRDS; ++j) {
 		initbird(ob, 1);
@@ -830,7 +820,7 @@ void initbird(OBJECTS *obo, int i)
 	ob->ob_life = BIRDLIFE;
 	ob->ob_owner = obo;
 	ob->ob_newsym = symbol_bird[0];
-	ob->ob_drawf = dispbird;
+	ob->ob_drawf = NULL;
 	ob->ob_movef = movebird;
 	ob->ob_clr = obo->ob_clr;
 	insertx(ob, &topobj);
@@ -869,12 +859,12 @@ static void inittargets(void)
 {
 	OBJECTS *ob;
 	original_ob_t *orig_ob;
-	int i, ti;
+	int i;
 
 	numtarg[0] = 0;
 	numtarg[1] = 0;
 
-	for (i = 0, ti = 0; i < MAX_TARG; i++) {
+	for (i = 0; i < currgame->gm_num_targets; i++) {
 		orig_ob = &currgame->gm_targets[i];
 		switch (orig_ob->type) {
 			case TARGET:
@@ -893,8 +883,6 @@ static void inittargets(void)
 		if (ob != NULL) {
 			ob->ob_original_ob = orig_ob;
 			insertx(ob, &topobj);
-			targets[ti] = ob;
-			++ti;
 		}
 	}
 }
@@ -941,7 +929,6 @@ void swinitlevel(void)
 		init2asy();
 	} else {
 		maxcrash = MAXCRASH;
-		currgame = &swgames[0];
 
 		// single player
 		
@@ -956,15 +943,15 @@ void swinitlevel(void)
 	initdisp(NO);
 	initgdep();
 
-	inplay = TRUE;
-
 	// sdh 16/11/2001: this needs to be reset with each new game
 	// to keep netgames in sync if we have already played
 
 	countmove = 0;
+	successful_flight = false;
 
-	for (i=0; i<num_players; ++i)
+	for (i=0; i<num_players; ++i) {
 		latest_player_time[i] = 0;
+	}
 }
 
 void swrestart(void)
@@ -1010,11 +997,11 @@ void swrestart(void)
 
 void swinit(int argc, char *argv[])
 {
-	BOOL n = FALSE;
-	BOOL s = FALSE;
-	BOOL c = FALSE;
-	BOOL a = FALSE;
-	BOOL k = FALSE;
+	bool n = false;
+	bool s = false;
+	bool c = false;
+	bool a = false;
+	bool k = false;
 	int modeset = 0, keyset;
 	int i;
 
@@ -1045,8 +1032,7 @@ void swinit(int argc, char *argv[])
 			asynmode = ASYN_LISTEN;
 		} else if (!strcasecmp(argv[i], "-j")) {
 			if (i + 1 >= argc) {
-				fprintf(stderr, "insufficient arguments to -j\n");
-				exit(-1);
+				error_exit("insufficient arguments to -j");
 			}
 			a = 1;
 			asynmode = ASYN_CONNECT;
@@ -1065,7 +1051,7 @@ void swinit(int argc, char *argv[])
 
 	soundflg = !soundflg;
 	if (modeset && keyset) {
-		titleflg = TRUE;
+		titleflg = true;
 	}
 
 	initseed();
@@ -1074,8 +1060,7 @@ void swinit(int argc, char *argv[])
 
 	symbol_generate();
 
-	// initialize video
-
+	Timer_Init();
 	Vid_Init();
 
 	// dont init speaker if started with -q (quiet)
@@ -1083,9 +1068,12 @@ void swinit(int argc, char *argv[])
 		Speaker_Init();		// init pc speaker
 	}
 
-	//        explseed = histinit( explseed );
+	// initgrnd() below needs currgame initialized to set the contents of
+	// the ground[] array for the title screen.
+	currgame = &original_level;
+
 	initsndt();
-	initgrnd();           // needed for title screen
+	initgrnd();
 	
 	// set playmode if we can, from command line options
 
@@ -1097,103 +1085,9 @@ void swinit(int argc, char *argv[])
 		PLAYMODE_UNSET;
 }
 
-//---------------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.27  2005/05/29 19:46:10  fraggle
-// Fix up autotools build. Fix "make dist".
-//
-// Revision 1.26  2005/04/29 19:58:01  fraggle
-// Stop 's' on the menu toggling sound when the game starts
-//
-// Revision 1.25  2005/04/29 19:25:28  fraggle
-// Update copyright to 2005
-//
-// Revision 1.24  2005/04/29 18:01:20  fraggle
-// Fix bug where unable to fly after reaching second level
-//
-// Revision 1.23  2005/04/29 17:18:29  fraggle
-// Dont display nonexistant planes on the map
-//
-// Revision 1.22  2005/04/29 11:20:28  fraggle
-// Remove ghost planes.  Split off status bar code into a separate file.
-//
-// Revision 1.21  2005/04/29 10:10:12  fraggle
-// "Medals" feature
-// By Christoph Reichenbach <creichen@gmail.com>
-//
-// Revision 1.20  2005/04/28 10:54:25  fraggle
-// -d option to specify start level
-//  (Thanks to Christoph Reichenbach <creichen@machine.cs.colorado.edu>)
-// Thanks also to Christoph for the plane chasing patch (I forgot to include
-// his name in the commit message)
-//
-// Revision 1.19  2004/10/25 20:02:11  fraggle
-// Fix spelling error: guage -> gauge
-//
-// Revision 1.18  2004/10/25 19:58:06  fraggle
-// Remove 'goingsun' global variable
-//
-// Revision 1.17  2004/10/20 19:00:01  fraggle
-// Remove currobx, endsts variables
-//
-// Revision 1.16  2004/10/15 22:28:39  fraggle
-// Remove some dead variables and code
-//
-// Revision 1.15  2004/10/15 21:30:58  fraggle
-// Improve multiplayer
-//
-// Revision 1.14  2004/10/15 18:51:24  fraggle
-// Fix the map. Rename dispworld to dispmap as this is what it really does.
-//
-// Revision 1.13  2004/10/15 18:06:16  fraggle
-// Fix copyright notice
-//
-// Revision 1.12  2004/10/15 17:52:32  fraggle
-// Clean up compiler warnings. Rename swmisc.c -> swtext.c as this more
-// accurately describes what the file does.
-//
-// Revision 1.11  2004/10/15 17:23:32  fraggle
-// Restore HUD splats
-//
-// Revision 1.10  2004/10/15 16:39:32  fraggle
-// Unobfuscate some parts
-//
-// Revision 1.9  2004/10/14 08:48:46  fraggle
-// Wrap the main function in system-specific code.  Remove g_argc/g_argv.
-// Fix crash when unable to initialise video subsystem.
-//
-// Revision 1.8  2003/06/08 18:41:01  fraggle
-// Merge changes from 1.7.0 -> 1.7.1 into HEAD
-//
-// Revision 1.7  2003/06/08 03:41:41  fraggle
-// Remove auxdisp buffer totally, and all associated functions
-//
-// Revision 1.6  2003/06/08 02:39:25  fraggle
-// Initial code to remove XOR based drawing
-//
-// Revision 1.5.2.2  2003/06/08 18:16:38  fraggle
-// Fix networking and some compile bugs
-//
-// Revision 1.5.2.1  2003/06/08 17:08:17  fraggle
-// Fix variable declared in wrong place
-//
-// Revision 1.5  2003/06/04 17:13:26  fraggle
-// Remove disprx, as it is implied from displx anyway.
-//
-// Revision 1.4  2003/06/04 15:33:53  fraggle
-// Store global argc/argv for gtk_init
-//
-// Revision 1.3  2003/04/05 22:44:04  fraggle
-// Remove some useless functions from headers, make them static if they
-// are not used by other files
-//
-// Revision 1.2  2003/04/05 22:31:29  fraggle
-// Remove PLAYMODE_MULTIPLE and swnetio.c
-//
-// Revision 1.1.1.1  2003/02/14 19:03:13  fraggle
-// Initial Sourceforge CVS import
 //
+// 2003-02-14: Code was checked into version control; no further entries
+// will be added to this log.
 //
 // sdh 14/2/2003: change license header to GPL
 // sdh 27/06/2002: move symbols to new sopsym_t format,
@@ -1241,5 +1135,3 @@ void swinit(int argc, char *argv[])
 // 85-10-31        Atari
 // 84-02-02        Development
 //
-//---------------------------------------------------------------------------
-
