@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//---------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 1984-2000 David L. Clark
 // Copyright(C) 2001-2005 Simon Howard
@@ -11,24 +7,17 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//---------------------------------------------------------------------------
 //
 //        swmove   -      SW move all objects and players
 //
-//---------------------------------------------------------------------------
 
 #include "sw.h"
 #include "swauto.h"
 #include "swcollsn.h"
 #include "swdisp.h"
 #include "swend.h"
-#include "swground.h"
 #include "swinit.h"
 #include "swmain.h"
 #include "swmove.h"
@@ -36,9 +25,17 @@
 #include "swsound.h"
 #include "swsymbol.h"
 #include "swtitle.h"
-#include "swutil.h"
 
-static BOOL quit;
+// If the player manages to keep the plane in the air this long, they
+// have got the hang of the controls and don't need any more help.
+#define SUCCESSFUL_FLIGHT_TIME (8 /* seconds */ * FPS)
+
+static bool movepln(OBJECTS *ob);
+static void interpret(OBJECTS *ob, int key);
+
+static bool quit;
+static int last_ground_time = 0;
+bool successful_flight = false;
 
 void swmove(void)
 {
@@ -64,6 +61,11 @@ void swmove(void)
 	}
 
 	++countmove;
+	if (consoleplayer->ob_athome) {
+		last_ground_time = countmove;
+	} else if (countmove - last_ground_time > SUCCESSFUL_FLIGHT_TIME) {
+		successful_flight = true;
+	}
 }
 
 
@@ -121,8 +123,6 @@ static void refuel(OBJECTS *ob)
 {
 	// sdh 26/10/2001: top up stuff, if anything happens update
 	// the gauges (now a single function)
-	// sdh 27/10/2001: fix refueling in parallel (was a single
-	// set of ||'s and was being shortcircuited)
 
 	topup(&ob->ob_life, MAXFUEL);
 	topup(&ob->ob_rounds, MAXROUNDS);
@@ -164,11 +164,11 @@ static int symangle(OBJECTS * ob)
 	}
 }
 
-BOOL moveplyr(OBJECTS *ob)
+bool moveplyr(OBJECTS *ob)
 {
 	int multkey;
 
-	compplane = FALSE;
+	compplane = false;
 	plyrplane = player == ob->ob_plrnum;
 
 	endstat = consoleplayer->ob_endsts;
@@ -200,7 +200,7 @@ BOOL moveplyr(OBJECTS *ob)
 	/*
 	if (dispcnt) {
 		ob->ob_flaps = 0;
-		ob->ob_bfiring = ob->ob_bombing = FALSE;
+		ob->ob_bfiring = ob->ob_bombing = false;
 		ob->ob_mfiring = NULL;
 	}*/
 
@@ -237,7 +237,7 @@ BOOL moveplyr(OBJECTS *ob)
 
 
 
-void interpret(OBJECTS *ob, int key)
+static void interpret(OBJECTS *ob, int key)
 {
 	obstate_t state;
 
@@ -262,19 +262,19 @@ void interpret(OBJECTS *ob, int key)
 
 		if (key & K_BREAK) {
 			ob->ob_life = QUIT;
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 			if (ob->ob_athome) {
 				ob->ob_state = state = CRASHED;
 				ob->ob_hitcount = 0;
 			}
 			if (plyrplane) {
-				quit = TRUE;
+				quit = true;
 			}
 		}
 
 		if (key & K_HOME) {
 			if (state == FLYING || state == WOUNDED) {
-				ob->ob_home = TRUE;
+				ob->ob_home = true;
 			}
 		}
 	}
@@ -283,31 +283,34 @@ void interpret(OBJECTS *ob, int key)
 	 || (state != WOUNDED && state != WOUNDSTALL)) {
 		if (key & K_FLAPU) {
 			++ob->ob_flaps;
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 		}
 
 		if (key & K_FLAPD) {
 			--ob->ob_flaps;
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 		}
 
-		if (key & K_FLIP) {
+		// We don't allow flipping upside down while sitting
+		// on the runway, that would be silly (this was a bug
+		// in the original game).
+		if ((key & K_FLIP) && !ob->ob_athome) {
 			ob->ob_orient = !ob->ob_orient;
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 		}
 
 		if (key & K_DEACC) {
 			if (ob->ob_accel) {
 				--ob->ob_accel;
 			}
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 		}
 
 		if (key & K_ACCEL) {
 			if (ob->ob_accel < MAX_THROTTLE) {
 				++ob->ob_accel;
 			}
-			ob->ob_home = FALSE;
+			ob->ob_home = false;
 		}
 	}
 
@@ -320,11 +323,11 @@ void interpret(OBJECTS *ob, int key)
 	}
 
 	if ((key & K_BOMB) && state < FINISHED) {
-		ob->ob_bombing = TRUE;
+		ob->ob_bombing = true;
 	}
 
 	if ((key & K_STARBURST) && state < FINISHED) {
-		ob->ob_bfiring = TRUE;
+		ob->ob_bfiring = true;
 	}
 
 	if (key & K_SOUND) {
@@ -342,15 +345,15 @@ void interpret(OBJECTS *ob, int key)
 	}
 }
 
-BOOL movecomp(OBJECTS *ob)
+bool movecomp(OBJECTS *ob)
 {
 	int rc;
 
-	compplane = TRUE;
-	plyrplane = FALSE;
+	compplane = true;
+	plyrplane = false;
 
 	ob->ob_flaps = 0;
-	ob->ob_bfiring = ob->ob_bombing = FALSE;
+	ob->ob_bfiring = ob->ob_bombing = false;
 	ob->ob_mfiring = NULL;
 
 	endstat = ob->ob_endsts;
@@ -396,7 +399,7 @@ BOOL movecomp(OBJECTS *ob)
 	return rc;
 }
 
-static BOOL stallpln(OBJECTS *ob)
+static bool stallpln(OBJECTS *ob)
 {
 	ob->ob_ldx = ob->ob_ldy = ob->ob_orient = ob->ob_dx = 0;
 	ob->ob_angle = 7 * ANGLES / 8;
@@ -405,14 +408,14 @@ static BOOL stallpln(OBJECTS *ob)
 	ob->ob_hitcount = STALLCOUNT;
 	ob->ob_state =
 		ob->ob_state == WOUNDED ? WOUNDSTALL : STALLED;
-	ob->ob_athome = FALSE;
+	ob->ob_athome = false;
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL movepln(OBJECTS *ob)
+static bool movepln(OBJECTS *ob)
 {
 	int nangle, nspeed, limit, update;
 	obstate_t state, newstate;
@@ -428,7 +431,7 @@ BOOL movepln(OBJECTS *ob)
 	switch (state) {
 	case FINISHED:
 	case WAITING:
-		return FALSE;
+		return false;
 
 	case CRASHED:
 		--ob->ob_hitcount;
@@ -487,7 +490,7 @@ BOOL movepln(OBJECTS *ob)
 		if (stalled) {
 			if (playmode == PLAYMODE_NOVICE) {
 				ob->ob_angle = (3 * ANGLES / 4);
-				stalled = FALSE;
+				stalled = false;
 			} else {
 				stallpln(ob);
 				state = ob->ob_state;
@@ -540,16 +543,16 @@ BOOL movepln(OBJECTS *ob)
 			if (!stalled && nspeed < gminspeed
 			 && playmode != PLAYMODE_NOVICE) {
 				--nspeed;
-				update = TRUE;
+				update = true;
 			} else {
 				limit = gminspeed
 				      + ob->ob_accel + gravity[nangle];
 				if (nspeed < limit) {
 					++nspeed;
-					update = TRUE;
+					update = true;
 				} else if (nspeed > limit) {
 					--nspeed;
-					update = TRUE;
+					update = true;
 				}
 			}
 		}
@@ -602,7 +605,7 @@ BOOL movepln(OBJECTS *ob)
 		}
 
 		if (ob->ob_speed) {
-			ob->ob_athome = FALSE;
+			ob->ob_athome = false;
 		}
 		break;
 	default:
@@ -630,8 +633,8 @@ BOOL movepln(OBJECTS *ob)
 
 	if (x < 0) {
 		x = ob->ob_x = 0;
-	} else if (x >= (MAX_X - 16)) {
-		x = ob->ob_x = MAX_X - 16;
+	} else if (x >= (currgame->gm_max_x - 16)) {
+		x = ob->ob_x = currgame->gm_max_x - 16;
 	}
 
 	if (!compplane
@@ -667,7 +670,7 @@ BOOL movepln(OBJECTS *ob)
 		return plyrplane || ob->ob_state < FINISHED;
 	}
 
-	return FALSE;
+	return false;
 }
 
 
@@ -691,7 +694,7 @@ static void adjustfall(OBJECTS *ob)
 }
 
 
-BOOL moveshot(OBJECTS *ob)
+bool moveshot(OBJECTS *ob)
 {
 	int x, y;
 
@@ -701,24 +704,25 @@ BOOL moveshot(OBJECTS *ob)
 
 	if (ob->ob_life <= 0) {
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	movexy(ob, &x, &y);
 
-	if (y >= MAX_Y || y <= (int) ground[x] || x < 0 || x >= MAX_X) {
+	if (y >= MAX_Y || x < 0 || x >= currgame->gm_max_x
+	 || y <= (int) ground[x]) {
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	insertx(ob, ob->ob_xnext);
 	ob->ob_newsym = &symbol_pixel;
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL movebomb(OBJECTS *ob)
+bool movebomb(OBJECTS *ob)
 {
 	int x, y;
 
@@ -727,7 +731,7 @@ BOOL movebomb(OBJECTS *ob)
 	if (ob->ob_life < 0) {
 		deallobj(ob);
 		ob->ob_state = FINISHED;
-		return FALSE;
+		return false;
 	}
 
 	adjustfall(ob);
@@ -738,26 +742,26 @@ BOOL movebomb(OBJECTS *ob)
 
 	movexy(ob, &x, &y);
 
-	if (y < 0 || x < 0 || x >= MAX_X) {
+	if (y < 0 || x < 0 || x >= currgame->gm_max_x) {
 		deallobj(ob);
 		stopsound(ob);
 		ob->ob_state = FINISHED;
-		return FALSE;
+		return false;
 	}
 
 	ob->ob_newsym = symbol_bomb[symangle(ob)];
 	insertx(ob, ob->ob_xnext);
 
 	if (y >= MAX_Y) {
-		return FALSE;
+		return false;
 	}
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL movemiss(OBJECTS *ob)
+bool movemiss(OBJECTS *ob)
 {
 	int x, y, angle;
 	OBJECTS *obt;
@@ -767,7 +771,7 @@ BOOL movemiss(OBJECTS *ob)
 	if (ob->ob_life < 0) {
 		deallobj(ob);
 		ob->ob_state = FINISHED;
-		return FALSE;
+		return false;
 	}
 
 	if (ob->ob_state == FLYING) {
@@ -800,25 +804,25 @@ BOOL movemiss(OBJECTS *ob)
 		movexy(ob, &x, &y);
 	}
 
-	if (y < 0 || x < 0 || x >= MAX_X) {
+	if (y < 0 || x < 0 || x >= currgame->gm_max_x) {
 		deallobj(ob);
 		ob->ob_state = FINISHED;
-		return FALSE;
+		return false;
 	}
 
 	ob->ob_newsym = symbol_missile[ob->ob_angle];
 	insertx(ob, ob->ob_xnext);
 
 	if (y >= MAX_Y) {
-		return FALSE;
+		return false;
 	}
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL moveburst(OBJECTS *ob)
+bool moveburst(OBJECTS *ob)
 {
 	int x, y;
 
@@ -826,16 +830,16 @@ BOOL moveburst(OBJECTS *ob)
 	if (ob->ob_life < 0) {
 		ob->ob_owner->ob_missiletarget = NULL;
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	adjustfall(ob);
 	movexy(ob, &x, &y);
 
-	if (y <= (int) ground[x] || x < 0 || x >= MAX_X) {
+	if (x < 0 || x >= currgame->gm_max_x || y <= (int) ground[x]) {
 		ob->ob_owner->ob_missiletarget = NULL;
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	ob->ob_owner->ob_missiletarget = ob;
@@ -848,7 +852,7 @@ BOOL moveburst(OBJECTS *ob)
 
 
 
-BOOL movetarg(OBJECTS *ob)
+bool movetarg(OBJECTS *ob)
 {
 	int r;
 	OBJECTS *obp;
@@ -880,12 +884,12 @@ BOOL movetarg(OBJECTS *ob)
 		ob->ob_newsym = symbol_target_hit;
 	}
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL moveexpl(OBJECTS * obp)
+bool moveexpl(OBJECTS * obp)
 {
 	OBJECTS *ob;
 	int x, y;
@@ -899,7 +903,7 @@ BOOL moveexpl(OBJECTS * obp)
 			stopsound(ob);
 		}
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	--ob->ob_life;
@@ -921,12 +925,12 @@ BOOL moveexpl(OBJECTS * obp)
 
 	movexy(ob, &x, &y);
 
-	if (x < 0 || x >= MAX_X || y <= (int) ground[x]) {
+	if (x < 0 || x >= currgame->gm_max_x || y <= (int) ground[x]) {
 		if (orient) {
 			stopsound(ob);
 		}
 		deallobj(ob);
-		return (FALSE);
+		return (false);
 	}
 	++ob->ob_hitcount;
 
@@ -938,7 +942,7 @@ BOOL moveexpl(OBJECTS * obp)
 
 
 
-BOOL movesmok(OBJECTS * obp)
+bool movesmok(OBJECTS * obp)
 {
 	OBJECTS *ob;
 	obstate_t state;
@@ -953,16 +957,16 @@ BOOL movesmok(OBJECTS * obp)
 	 || (state != FALLING && state != WOUNDED
 	  && state != WOUNDSTALL && state != CRASHED)) {
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 	ob->ob_newsym = &symbol_pixel;
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL moveflck(OBJECTS * obp)
+bool moveflck(OBJECTS * obp)
 {
 	OBJECTS *ob;
 	int x, y;
@@ -972,7 +976,7 @@ BOOL moveflck(OBJECTS * obp)
 
 	if (ob->ob_life == -1) {
 		deallobj(ob);
-		return FALSE;
+		return false;
 	}
 
 	--ob->ob_life;
@@ -992,21 +996,21 @@ BOOL moveflck(OBJECTS * obp)
 	movexy(ob, &x, &y);
 	insertx(ob, ob->ob_xnext);
 	ob->ob_newsym = symbol_flock[ob->ob_orient];
-	return TRUE;
+	return true;
 }
 
 
-static BOOL checkwall(OBJECTS *obp, int direction)
+static bool checkwall(OBJECTS *obp, int direction)
 {
 	int check_x, cnt;
 
 	check_x = obp->ob_x;
 	for (cnt = 0; cnt < 20; ++cnt) {
-		if (check_x < 0 || check_x >= MAX_X) {
-			return TRUE;
+		if (check_x < 0 || check_x >= currgame->gm_max_x) {
+			return true;
 		}
 		if ((int) ground[check_x] > obp->ob_y + 10) {
-			return TRUE;
+			return true;
 		}
 		if (direction < 0) {
 			--check_x;
@@ -1014,10 +1018,10 @@ static BOOL checkwall(OBJECTS *obp, int direction)
 			++check_x;
 		}
 	}
-	return FALSE;
+	return false;
 }
 
-BOOL movebird(OBJECTS * obp)
+bool movebird(OBJECTS * obp)
 {
 	OBJECTS *ob;
 	int x, y;
@@ -1028,7 +1032,7 @@ BOOL movebird(OBJECTS * obp)
 
 	if (ob->ob_life == -1) {
 		deallobj(ob);
-		return FALSE;
+		return false;
 	} else if (ob->ob_life == -2) {
 		ob->ob_dy = -ob->ob_dy;
 		ob->ob_dx = (countmove & 7) - 4;
@@ -1051,27 +1055,28 @@ BOOL movebird(OBJECTS * obp)
 
 	insertx(ob, ob->ob_xnext);
 	ob->ob_newsym = symbol_bird[ob->ob_orient];
-	if (y >= MAX_Y || y <= (int) ground[x] || x < 0 || x >= MAX_X) {
+	if (x < 0 || x >= currgame->gm_max_x
+	 || y >= MAX_Y || y <= (int) ground[x]) {
 		ob->ob_y -= ob->ob_dy;
 		ob->ob_life = -2;
-		return FALSE;
+		return false;
 	}
-	return TRUE;
+	return true;
 }
 
 
 
 
-BOOL moveox(OBJECTS * ob)
+bool moveox(OBJECTS * ob)
 {
 	ob->ob_newsym = symbol_ox[ob->ob_state != STANDING];
-	return TRUE;
+	return true;
 }
 
 
 
 
-BOOL crashpln(OBJECTS * obp)
+bool crashpln(OBJECTS * obp)
 {
 	OBJECTS *ob, *obo;
 
@@ -1084,7 +1089,7 @@ BOOL crashpln(OBJECTS * obp)
 	}
 
 	ob->ob_state = CRASHED;
-	ob->ob_athome = FALSE;
+	ob->ob_athome = false;
 	ob->ob_dx = ob->ob_dy = ob->ob_ldx = ob->ob_ldy = ob->ob_speed = 0;
 
 	obo = &oobjects[ob->ob_index];
@@ -1092,12 +1097,12 @@ BOOL crashpln(OBJECTS * obp)
 	                && (abs(obo->ob_y - ob->ob_y) < SAFERESET))
 	    ? (MAXCRCOUNT << 1) : MAXCRCOUNT;
 
-	return TRUE;
+	return true;
 }
 
 
 
-BOOL hitpln(OBJECTS * obp)
+bool hitpln(OBJECTS * obp)
 {
 	OBJECTS *ob;
 
@@ -1105,13 +1110,13 @@ BOOL hitpln(OBJECTS * obp)
 	ob->ob_ldx = ob->ob_ldy = 0;
 	ob->ob_hitcount = FALLCOUNT;
 	ob->ob_state = FALLING;
-	ob->ob_athome = FALSE;
+	ob->ob_athome = false;
 
-	return TRUE;
+	return true;
 }
 
 
-BOOL insertx(OBJECTS *ob, OBJECTS *obp)
+bool insertx(OBJECTS *ob, OBJECTS *obp)
 {
 	OBJECTS *obs;
 	int obx;
@@ -1140,7 +1145,7 @@ BOOL insertx(OBJECTS *ob, OBJECTS *obp)
 		ob->ob_xnext->ob_xprev = ob;
 	}
 
-	return TRUE;
+	return true;
 }
 
 
@@ -1155,74 +1160,9 @@ void deletex(OBJECTS *ob)
 	}
 }
 
-
-
-//---------------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.19  2005/04/29 19:25:28  fraggle
-// Update copyright to 2005
-//
-// Revision 1.18  2005/04/29 11:20:35  fraggle
-// Remove ghost planes.  Split off status bar code into a separate file.
-//
-// Revision 1.17  2005/04/29 10:10:12  fraggle
-// "Medals" feature
-// By Christoph Reichenbach <creichen@gmail.com>
-//
-// Revision 1.16  2004/10/25 20:02:11  fraggle
-// Fix spelling error: guage -> gauge
-//
-// Revision 1.15  2004/10/25 19:58:06  fraggle
-// Remove 'goingsun' global variable
-//
-// Revision 1.14  2004/10/20 19:00:01  fraggle
-// Remove currobx, endsts variables
-//
-// Revision 1.13  2004/10/15 21:30:58  fraggle
-// Improve multiplayer
-//
-// Revision 1.12  2004/10/15 18:51:24  fraggle
-// Fix the map. Rename dispworld to dispmap as this is what it really does.
-//
-// Revision 1.11  2004/10/15 16:39:32  fraggle
-// Unobfuscate some parts
-//
-// Revision 1.10  2003/06/08 18:41:01  fraggle
-// Merge changes from 1.7.0 -> 1.7.1 into HEAD
-//
-// Revision 1.9  2003/06/08 03:41:42  fraggle
-// Remove auxdisp buffer totally, and all associated functions
-//
-// Revision 1.8  2003/06/08 02:48:45  fraggle
-// Remove dispdx, always calculated displx from the current player position
-// and do proper edge-of-level bounds checking
-//
-// Revision 1.7  2003/06/08 02:39:25  fraggle
-// Initial code to remove XOR based drawing
-//
-// Revision 1.6.2.1  2003/06/08 18:16:38  fraggle
-// Fix networking and some compile bugs
-//
-// Revision 1.6  2003/06/04 17:13:26  fraggle
-// Remove disprx, as it is implied from displx anyway.
-//
-// Revision 1.5  2003/06/04 17:02:37  fraggle
-// Remove some obfuscation and dead code
-//
-// Revision 1.4  2003/04/06 22:01:02  fraggle
-// Fix compile warnings
-//
-// Revision 1.3  2003/04/05 22:44:04  fraggle
-// Remove some useless functions from headers, make them static if they
-// are not used by other files
-//
-// Revision 1.2  2003/04/05 22:31:29  fraggle
-// Remove PLAYMODE_MULTIPLE and swnetio.c
-//
-// Revision 1.1.1.1  2003/02/14 19:03:15  fraggle
-// Initial Sourceforge CVS import
 //
+// 2003-02-14: Code was checked into version control; no further entries
+// will be added to this log.
 //
 // sdh 14/2/2003: change license header to GPL
 //                autohome on harry keys mode fixed.
@@ -1251,6 +1191,3 @@ void deletex(OBJECTS *ob)
 // 85-10-31        Atari
 // 84-02-07        Development
 //
-//---------------------------------------------------------------------------
-
-
