@@ -1,7 +1,3 @@
-// Emacs style mode select -*- C++ -*-
-//---------------------------------------------------------------------------
-//
-// $Id$
 //
 // Copyright(C) 1984-2000 David L. Clark
 // Copyright(C) 2001-2005 Simon Howard
@@ -11,21 +7,15 @@
 // Free Software Foundation; either version 2 of the License, or (at your
 // option) any later version. This program is distributed in the hope that
 // it will be useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
-// the GNU General Public License for more details. You should have
-// received a copy of the GNU General Public License along with this
-// program; if not, write to the Free Software Foundation, Inc., 59 Temple
-// Place - Suite 330, Boston, MA 02111-1307, USA.
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-//---------------------------------------------------------------------------
 //
 // Status bar code
 //
-//---------------------------------------------------------------------------
 
 #include "video.h"
 
-#include "swground.h"
+#include "swinit.h"
 #include "swmain.h"
 #include "swtext.h"
 
@@ -150,7 +140,7 @@ static void dispmap(void)
 
 	// draw ground
 
-	for (x = 0; x < MAX_X; ++x) {
+	for (x = 0; x < currgame->gm_max_x; ++x) {
 
 		if (ground[x] > maxh) {
 			maxh = ground[x];
@@ -206,15 +196,3 @@ void dispstatusbar(void)
 		dispmedals(consoleplayer);
 	}
 }
-
-
-
-//--------------------------------------------------------------------------
-//
-// $Log$
-// Revision 1.7  2005/06/01 10:43:35  fraggle
-// Add missing log tags
-//
-//
-//--------------------------------------------------------------------------
-
